namespace XamPivotGridXampl
{
    public class BucketRiskDTO
    {
        public Instrument Instrument { get; set; }

        public string AssetType { get { return Instrument.Type; } }
        public string AssetId { get { return Instrument.Key; } }

        public string Country
        {
            get
            {
                var bond = Instrument as Bond;
                if (bond == null)
                {
                    return string.Empty;
                }
                return bond.Country;
            }
        }

        public string Issuer
        {
            get
            {
                var bond = Instrument as Bond;
                if (bond == null)
                {
                    return string.Empty;
                }
                return bond.Issuer;
            }
        }

        public string RatingFitch
        {
            get
            {
                var bond = Instrument as Bond;
                if (bond == null)
                {
                    return string.Empty;
                }
                return bond.RatingFitch;
            }
        }

        public string RatingSP
        {
            get
            {
                var bond = Instrument as Bond;
                if (bond == null)
                {
                    return string.Empty;
                }
                return bond.RatingStandardPoors;
            }
        }

        public string Currency
        {
            get
            {
                var bond = Instrument as Bond;
                if (bond == null)
                {
                    return string.Empty;
                }
                return bond.Currency;
            }
        }

        public decimal Risk { get; set; }
        public string Tenor { get; set; }
        public string Curve { get; set; }
        public string Book { get; set; }

        public override bool Equals(object obj)
        {
            if (ReferenceEquals(null, obj))
            {
                return false;
            }
            if (ReferenceEquals(this, obj))
            {
                return true;
            }
            return obj.GetType() == GetType() && Equals((BucketRiskDTO)obj);
        }

        protected bool Equals(BucketRiskDTO other)
        {
            return Equals(Instrument, other.Instrument)
                && string.Equals(Tenor, other.Tenor)
                && string.Equals(Curve, other.Curve)
                && string.Equals(Book, other.Book);
        }

        public override int GetHashCode()
        {
            unchecked
            {
                var hashCode = (Instrument != null ? Instrument.GetHashCode() : 0);
                hashCode = (hashCode * 397) ^ (Tenor != null ? Tenor.GetHashCode() : 0);
                hashCode = (hashCode * 397) ^ (Curve != null ? Curve.GetHashCode() : 0);
                hashCode = (hashCode * 397) ^ (Book != null ? Book.GetHashCode() : 0);
                return hashCode;
            }
        }
        
    }
}