using System.Collections.Generic;
using System.IO;
using System.Text;
using System.Windows.Data;
using System.Windows.Threading;
using System.Xml;
using System.Xml.Serialization;

namespace XamPivotGridXampl
{
    public class MainWindowViewModel : Bindable
    {
        private readonly BucketRiskFlatDataSource _flatDataSource;
        private readonly IBucketRiskService _bucketRiskService;

        public MainWindowViewModel()
            : this(BucketRiskFlatDataSourceFactoryRealService.Create(), BucketRiskServiceClientFactory.GetBucketRiskServiceForTesting())
        {
        }

        internal MainWindowViewModel(BucketRiskFlatDataSource flatDataSource, IBucketRiskService bucketRiskService)
        {
            _flatDataSource = flatDataSource;
            _bucketRiskService = bucketRiskService;
            LayoutManager = new BucketRiskLayoutManager(new GuiHelper(Dispatcher.CurrentDispatcher), _flatDataSource);
            BucketRiskLayoutItems = new CompositeCollection {new CollectionContainer {Collection = LayoutManager.Layouts}};
            Refresh();
            CanRefreshRisk = true;
        }

        private bool _canRefreshRisk;

        public bool CanRefreshRisk
        {
            get
            {
                return _canRefreshRisk;
            }
            set
            {
                if (value == _canRefreshRisk)
                {
                    return;
                }

                _canRefreshRisk = value;
                OnPropertyChanged();
            }
        }

        public CompositeCollection BucketRiskLayoutItems { get; private set; }

        public BucketRiskLayoutManager LayoutManager { get; private set; }

        public BucketRiskFlatDataSource FlatDataSource
        {
            get { return _flatDataSource; }
        }

        public void Refresh()
        {
            CanRefreshRisk = false;
            FlatDataSource.RefreshDataSource(_bucketRiskService.GetAll());
            CanRefreshRisk = true;
        }

        private void SaveLocalDtos(IEnumerable<BucketRiskDTO> bucketRiskDtos)
        {
            var serializer = new XmlSerializer(typeof(BucketRiskDTO[]));
            var responsePath = Path.Combine(Path.GetFullPath("DataMock"), "BucketRiskServiceResponse.xml");
            using (var streamWriter = new XmlTextWriter(responsePath, Encoding.Default))
            {
                serializer.Serialize(streamWriter, bucketRiskDtos);
            }
        }
    }
}